==> huaweicloudsdkvod-3.0.50-py2.py3-none-any.whl: huaweicloudsdkvod/v1/model/upload_meta_data_by_url_req.py <==
# coding: utf-8

import pprint
import re

import six





class UploadMetaDataByUrlReq:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'upload_metadatas': 'list[UploadMetaDataByUrl]'
    }

    attribute_map = {
        'upload_metadatas': 'upload_metadatas'
    }

    def __init__(self, upload_metadatas=None):
        """UploadMetaDataByUrlReq - a model defined in huaweicloud sdk"""
        
        

        self._upload_metadatas = None
        self.discriminator = None

        self.upload_metadatas = upload_metadatas

    @property
    def upload_metadatas(self):
        """Gets the upload_metadatas of this UploadMetaDataByUrlReq.

        待拉取创建的媒资元数据

        :return: The upload_metadatas of this UploadMetaDataByUrlReq.
        :rtype: list[UploadMetaDataByUrl]
        """
        return self._upload_metadatas

    @upload_metadatas.setter
    def upload_metadatas(self, upload_metadatas):
        """Sets the upload_metadatas of this UploadMetaDataByUrlReq.

        待拉取创建的媒资元数据

        :param upload_metadatas: The upload_metadatas of this UploadMetaDataByUrlReq.
        :type: list[UploadMetaDataByUrl]
        """
        self._upload_metadatas = upload_metadatas

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UploadMetaDataByUrlReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkvod-3.0.52-py2.py3-none-any.whl: huaweicloudsdkvod/v1/model/upload_meta_data_by_url_req.py <==
# coding: utf-8

import re
import six





class UploadMetaDataByUrlReq:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'upload_metadatas': 'list[UploadMetaDataByUrl]'
    }

    attribute_map = {
        'upload_metadatas': 'upload_metadatas'
    }

    def __init__(self, upload_metadatas=None):
        """UploadMetaDataByUrlReq - a model defined in huaweicloud sdk"""
        
        

        self._upload_metadatas = None
        self.discriminator = None

        self.upload_metadatas = upload_metadatas

    @property
    def upload_metadatas(self):
        """Gets the upload_metadatas of this UploadMetaDataByUrlReq.

        待拉取创建的媒资元数据

        :return: The upload_metadatas of this UploadMetaDataByUrlReq.
        :rtype: list[UploadMetaDataByUrl]
        """
        return self._upload_metadatas

    @upload_metadatas.setter
    def upload_metadatas(self, upload_metadatas):
        """Sets the upload_metadatas of this UploadMetaDataByUrlReq.

        待拉取创建的媒资元数据

        :param upload_metadatas: The upload_metadatas of this UploadMetaDataByUrlReq.
        :type: list[UploadMetaDataByUrl]
        """
        self._upload_metadatas = upload_metadatas

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UploadMetaDataByUrlReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
